@@ -516,14 +516,18 @@ static void
 _vte_table_extract_numbers(GValueArray **array,
 			   struct _vte_table_arginfo *arginfo)
 {
+	GValue value = {0,};
+	GValue subvalue = {0,};
+	GValueArray *subarray = NULL;
+	gssize i;
+
         if (G_UNLIKELY (*array == NULL)) {
                 *array = g_value_array_new(1);
         }
 
-	GValue value = {0,};
 	g_value_init(&value, G_TYPE_LONG);
-	gssize i = 0;
-        GValueArray *subarray = nullptr;
+	g_value_init(&subvalue, G_TYPE_VALUE_ARRAY);
+	i = 0;
 	do {
 		long total = 0;
 		for (; i < arginfo->length && arginfo->start[i] != ';' && arginfo->start[i] != ':'; i++) {
@@ -542,20 +546,13 @@ _vte_table_extract_numbers(GValueArray **array,
 				g_value_array_append(*array, &value);
 			} else {
 				g_value_array_append(subarray, &value);
-
-                                GValue subvalue = {0,};
-                                g_value_init(&subvalue, G_TYPE_VALUE_ARRAY);
-				g_value_take_boxed(&subvalue, subarray);
+				g_value_set_boxed(&subvalue, subarray);
 				g_value_array_append(*array, &subvalue);
-                                g_value_unset(&subvalue);
-
 				subarray = NULL;
 			}
 		}
 	} while (i++ < arginfo->length);
 	g_value_unset(&value);
-        if (subarray != nullptr)
-                g_value_array_free(subarray);
 }
 
 static void
