@@ -26,7 +26,12 @@
 #include <glib.h>
 #include "buffer.h"
 #include "vteconv.h"
-#include "vtedefines.hh"
+
+#ifdef VTE_COMPILATION
+#include "vte-private.h"
+#else
+#define VTE_UTF8_BPC                    (6) /* Maximum number of bytes used per UTF-8 character */
+#endif
 
 typedef size_t (*convert_func)(GIConv converter,
 			  const guchar **inbuf,
