@@ -2,18 +2,19 @@
  * Copyright (C) 2009,2010 Red Hat, Inc.
  * Copyright (C) 2013 Google, Inc.
  *
- * This library is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published
- * by the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  * Red Hat Author(s): Behdad Esfahbod
  * Google Author(s): Behdad Esfahbod
@@ -83,18 +84,16 @@
 #include <unistd.h>
 #include <zlib.h>
 
-#include "vteutils.h"
-
-#if WITH_GNUTLS
+#ifdef WITH_GNUTLS
 # include <gnutls/gnutls.h>
 # include <gnutls/crypto.h>
-#else
-#undef WITH_GNUTLS
 #endif
 
+#include "vteutils.h"
+
 G_BEGIN_DECLS
 
-#if WITH_GNUTLS
+#ifdef WITH_GNUTLS
 /* Currently the code requires that a stream cipher (e.g. GCM) is used
  * which can encrypt any amount of data without need for padding. */
 # define VTE_CIPHER_ALGORITHM    GNUTLS_CIPHER_AES_256_GCM
@@ -128,11 +127,7 @@ typedef guint8 _vte_overwrite_counter_t;
 
 /******************************************************************************************/
 
-#if !HAVE_EXPLICIT_BZERO
-#define explicit_bzero(s, n) memset((s), 0, (n))
-#endif
-
-#if !HAVE_PREAD
+#ifndef HAVE_PREAD
 #define pread _pread
 static inline gsize
 pread (int fd, char *data, gsize len, gsize offset)
@@ -143,7 +138,7 @@ pread (int fd, char *data, gsize len, gsize offset)
 }
 #endif
 
-#if !HAVE_PWRITE
+#ifndef HAVE_PWRITE
 #define pwrite _pwrite
 static inline gsize
 pwrite (int fd, char *data, gsize len, gsize offset)
@@ -835,10 +830,12 @@ _vte_boa_init (VteBoa *boa)
         datum_key.data = key;
         datum_key.size = VTE_CIPHER_KEY_SIZE;
         gnutls_cipher_init(&boa->cipher_hd, VTE_CIPHER_ALGORITHM, &datum_key, NULL);
-        explicit_bzero(key, VTE_CIPHER_KEY_SIZE);
+        /* FIXME: 738601#c52 the compiler might optimize this away, how to make sure it's erased?
+         * It's on the stack so maybe we can rest assured it'll be overwritten pretty soon. */
+        memset(key, 0, VTE_CIPHER_KEY_SIZE);
 
         /* Empty IV. */
-        explicit_bzero(&boa->iv, sizeof(boa->iv));
+        memset(&boa->iv, 0, sizeof(boa->iv));
 #endif
 
         boa->compressBound = _vte_boa_compressBound(VTE_BOA_BLOCKSIZE);
@@ -850,7 +847,7 @@ _vte_boa_finalize (GObject *object)
 #if !defined VTESTREAM_MAIN && defined WITH_GNUTLS
         VteBoa *boa = (VteBoa *) object;
 
-        explicit_bzero(&boa->iv, sizeof(boa->iv));
+        memset(&boa->iv, 0, sizeof(boa->iv));
 
         gnutls_cipher_deinit (boa->cipher_hd);
         gnutls_global_deinit ();
@@ -886,24 +883,25 @@ static gboolean
 _vte_boa_read_with_overwrite_counter (VteBoa *boa, gsize offset, char *data, _vte_overwrite_counter_t *overwrite_counter)
 {
         _vte_block_datalength_t compressed_len;
-        char *buf = g_newa(char, VTE_SNAKE_BLOCKSIZE);
+        gboolean ret = FALSE;
+        char *buf = (char *)g_malloc(VTE_SNAKE_BLOCKSIZE);
 
         g_assert_cmpuint (offset % VTE_BOA_BLOCKSIZE, ==, 0);
 
         /* Read */
         if (G_UNLIKELY (!_vte_snake_read (&boa->parent, OFFSET_BOA_TO_SNAKE(offset), buf)))
-                return FALSE;
+                goto out;
 
         compressed_len = *((_vte_block_datalength_t *) buf);
         *overwrite_counter = *((_vte_overwrite_counter_t *) (buf + VTE_BLOCK_DATALENGTH_SIZE));
 
         /* We could have read an empty block due to a previous disk full. Treat that as an error too. Perform other sanity checks. */
         if (G_UNLIKELY (compressed_len <= 0 || compressed_len > VTE_BOA_BLOCKSIZE || *overwrite_counter <= 0))
-                return FALSE;
+                goto out;
 
         /* Decrypt, bail out on tag mismatch */
         if (G_UNLIKELY (!_vte_boa_decrypt (boa, offset, *overwrite_counter, buf + VTE_BLOCK_DATALENGTH_SIZE + VTE_OVERWRITE_COUNTER_SIZE, compressed_len)))
-                return FALSE;
+                goto out;
 
         /* Uncompress, or copy if wasn't compressable */
         if (G_LIKELY (data != NULL)) {
@@ -915,7 +913,11 @@ _vte_boa_read_with_overwrite_counter (VteBoa *boa, gsize offset, char *data, _vt
                         g_assert_cmpuint (uncompressed_len, ==, VTE_BOA_BLOCKSIZE);
                 }
         }
-        return TRUE;
+        ret = TRUE;
+
+out:
+        g_free(buf);
+        return ret;
 }
 
 static gboolean
@@ -932,6 +934,8 @@ _vte_boa_read (VteBoa *boa, gsize offset, char *data)
 static void
 _vte_boa_write (VteBoa *boa, gsize offset, const char *data)
 {
+        _vte_block_datalength_t compressed_len = boa->compressBound;
+
         /* The overwrite counter is 1-based.  This is to make sure that the IV is never 0: 738601#c88,
            to make sure that an empty block (e.g. after a previous write failure) is always invalid,
            and to make unit testing easier */
@@ -939,8 +943,8 @@ _vte_boa_write (VteBoa *boa, gsize offset, const char *data)
 
         /* The helper buffer should be large enough to contain a whole snake block,
          * and also large enough to compress data that actually grows bigger during compression. */
-        char *buf = g_newa(char, MAX(VTE_SNAKE_BLOCKSIZE,
-                                     VTE_BLOCK_DATALENGTH_SIZE + VTE_OVERWRITE_COUNTER_SIZE + boa->compressBound));
+        char *buf = (char *)g_malloc(MAX(VTE_SNAKE_BLOCKSIZE,
+                                         VTE_BLOCK_DATALENGTH_SIZE + VTE_OVERWRITE_COUNTER_SIZE + boa->compressBound));
 
         g_assert_cmpuint (offset, >=, boa->tail);
         g_assert_cmpuint (offset, <=, boa->head);
@@ -960,13 +964,11 @@ _vte_boa_write (VteBoa *boa, gsize offset, const char *data)
                         _vte_snake_write (&boa->parent, OFFSET_BOA_TO_SNAKE(offset), buf, VTE_SNAKE_BLOCKSIZE);
                         /* Try to punch out from the FS */
                         _vte_snake_write (&boa->parent, OFFSET_BOA_TO_SNAKE(offset), "", 0);
-                        return;
+                        goto out;
                 }
                 overwrite_counter++;
         }
 
-        _vte_block_datalength_t compressed_len;
-
         /* Compress, or copy if uncompressable */
         compressed_len = _vte_boa_compress (buf + VTE_BLOCK_DATALENGTH_SIZE + VTE_OVERWRITE_COUNTER_SIZE, boa->compressBound,
                                             data, VTE_BOA_BLOCKSIZE);
@@ -987,6 +989,9 @@ _vte_boa_write (VteBoa *boa, gsize offset, const char *data)
         if (G_LIKELY (offset == boa->head)) {
                 boa->head += VTE_BOA_BLOCKSIZE;
         }
+
+out:
+        g_free(buf);
 }
 
 static void
@@ -1068,6 +1073,7 @@ static void
 _vte_file_stream_init (VteFileStream *stream)
 {
         stream->boa = (VteBoa *)g_object_new (VTE_TYPE_BOA, NULL);
+        _vte_boa_init (stream->boa);
 
         stream->rbuf = (char *)g_malloc(VTE_BOA_BLOCKSIZE);
         stream->wbuf = (char *)g_malloc(VTE_BOA_BLOCKSIZE);
@@ -1249,10 +1255,6 @@ G_END_DECLS
 
 #ifdef VTESTREAM_MAIN
 
-#ifdef __clang__
-#pragma clang diagnostic ignored "-Wstring-plus-int"
-#endif
-
 /* Some helpers. Macros rather than functions to report useful line numbers on failure. */
 
 /* Check for the file's exact contents */
